* Appendix Tables 6, 7, 8, and 9.


use "$dir/Oliver Upton - EJ 2022 - Cross Section.dta", clear		

	replace gdp_pc7074 = ln(gdp_pc7074 )
	replace consumption_pc7074 = ln(consumption_pc7074)
	
	gen nonFF = 0 
	replace nonFF = 1 if energyendowment==0
	label var nonFF "1 if No FF Endowments"
	
	gen gdp_pc7074_FF = gdp_pc7074 * energyendowment
	gen gdp_pc7074_nFF = gdp_pc7074 * nonFF
	
	gen consumption_pc7074_FF = consumption_pc7074 * energyendowment
	gen consumption_pc7074_nFF = consumption_pc7074 * nonFF
	
	* ----------------------
	* Appendix Table 6 - Beta Convergence with Interactions
	* ----------------------
	
	*GDP Per Capita
	reg avggrowthrate_40yr gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF, noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]
	
	reg avggrowthrate_40yr gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF $controls , noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]
	
	*Consumption Per Capita		
	reg cavggrowthrate_40yr consumption_pc7074_FF consumption_pc7074_nFF energyendowment nonFF, noconst robust
		lincom _b[consumption_pc7074_FF] - _b[consumption_pc7074_nFF]
	
	reg cavggrowthrate_40yr consumption_pc7074_FF consumption_pc7074_nFF energyendowment nonFF $controls, noconst robust
		lincom _b[consumption_pc7074_FF] - _b[consumption_pc7074_nFF]

	* ----------------------
	*  Appendix Table 7 - Resource Rents Robustness with Interactions
	* ----------------------
	
	*GDP Per Capita
	reg avggrowthrate_40yr gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF rents7074, noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]
	
	reg avggrowthrate_40yr gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF rents7074 $controls , noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]
	
	*Consumption Per Capita		
	reg cavggrowthrate_40yr consumption_pc7074_FF consumption_pc7074_nFF energyendowment nonFF rents7074, noconst robust
		lincom _b[consumption_pc7074_FF] - _b[consumption_pc7074_nFF]
	
	reg cavggrowthrate_40yr consumption_pc7074_FF consumption_pc7074_nFF energyendowment nonFF rents7074 $controls, noconst robust
		lincom _b[consumption_pc7074_FF] - _b[consumption_pc7074_nFF]
		
	* ----------------------
	* Appendix Table 8 - Share Primary Products Exports Robustness with Interactions
	* ----------------------
	
	*GDP Per Capita
	reg avggrowthrate_40yr gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF sxp, noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]
	
	reg avggrowthrate_40yr gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF sxp $controls , noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]

	*Consumption Per Capita		
	reg cavggrowthrate_40yr consumption_pc7074_FF consumption_pc7074_nFF energyendowment nonFF sxp, noconst robust
		lincom _b[consumption_pc7074_FF] - _b[consumption_pc7074_nFF]
	
	reg cavggrowthrate_40yr consumption_pc7074_FF consumption_pc7074_nFF energyendowment nonFF sxp $controls, noconst robust
		lincom _b[consumption_pc7074_FF] - _b[consumption_pc7074_nFF]		
		
		
	* ----------------------
	* Appendix Table 9 - Growth Components with Interactions
	* ----------------------
		
	use "$dir/Oliver Upton - EJ 2022 - Cross Section.dta", clear		
	
		gen nonFF = 0 
		replace nonFF = 1 if energyendowment==0
		label var nonFF "1 if No FF Endowments"
		
		drop if g_y7074==. |  g_k7074==. |  g_hc7074==. |  g_tfp7074==. 	//Smaller sample due to missing data for some of these variables.  
		tab energyendowment
		
		gen g_y_all = ( g_y7074 + g_y7579 + g_y8084 + g_y8589 + g_y9094 + g_y9599 + g_y0004 + g_y0509 + g_y1014 ) / 9
		gen g_k_all = ( g_k7074 + g_k7579 + g_k8084 + g_k8589 + g_k9094 + g_k9599 + g_k0004 + g_k0509 + g_k1014 ) / 9
		gen g_hc_all = ( g_hc7074 + g_hc7579 + g_hc8084 + g_hc8589 + g_hc9094 + g_hc9599 + g_hc0004 + g_hc0509 + g_hc1014 ) / 9
		gen g_tfp_all = ( g_tfp7074 + g_tfp7579 + g_tfp8084 + g_tfp8589 + g_tfp9094 + g_tfp9599 + g_tfp0004 + g_tfp0509 + g_tfp1014 ) / 9
	
		replace gdp_pc7074 = ln(gdp_pc7074)
			label var gdp_pc7074 "Log Real GDP per Capita - 1970-1974"	
		
		gen gdp_pc7074_FF = gdp_pc7074 * energyendowment
		gen gdp_pc7074_nFF = gdp_pc7074 * nonFF
		
		gen consumption_pc7074_FF = consumption_pc7074 * energyendowment
		gen consumption_pc7074_nFF = consumption_pc7074 * nonFF
	
	*------------------
	*Output Per Worker
	*------------------
	reg g_y_all gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF , noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]
	
	reg g_y_all gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF  $controls , noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]

	*------------------
	*Capital Per Worker
	*------------------
	reg g_k_all gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF , noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]
	
	reg g_k_all gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF  $controls , noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]

	*------------------
	*Human Capital Per Worker
	*------------------
	reg g_hc_all gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF , noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]
	
	reg g_hc_all gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF  $controls , noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]

	*------------------
	*TFP Per Worker
	*------------------
	reg g_tfp_all gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF , noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]
	
	reg g_tfp_all gdp_pc7074_FF gdp_pc7074_nFF energyendowment nonFF  $controls , noconst robust
		lincom _b[gdp_pc7074_FF] - _b[gdp_pc7074_nFF]
