* Table 6: Growth Components
* Also creates Figure 3 graphs. 

use "$dir/Oliver Upton - EJ 2022 - Cross Section.dta", clear		

	global controls_GC "oecd lat_abst avexpr  landlock africa other asia goldm iron silv zinc steplow deslow stepmid desmid drystep drywint"
	*Growth component controls do not include the variables used to calculate the growth components themselves (i.e. capital stock and human capital)


	drop if g_y7074==. |  g_k7074==. |  g_hc7074==. |  g_tfp7074==. 	//Smaller sample due to missing data for some of these variables.  
	tab energyendowment
	
	gen g_y_all = ( g_y7074 + g_y7579 + g_y8084 + g_y8589 + g_y9094 + g_y9599 + g_y0004 + g_y0509 + g_y1014 ) / 9
	gen g_k_all = ( g_k7074 + g_k7579 + g_k8084 + g_k8589 + g_k9094 + g_k9599 + g_k0004 + g_k0509 + g_k1014 ) / 9
	gen g_hc_all = ( g_hc7074 + g_hc7579 + g_hc8084 + g_hc8589 + g_hc9094 + g_hc9599 + g_hc0004 + g_hc0509 + g_hc1014 ) / 9
	gen g_tfp_all = ( g_tfp7074 + g_tfp7579 + g_tfp8084 + g_tfp8589 + g_tfp9094 + g_tfp9599 + g_tfp0004 + g_tfp0509 + g_tfp1014 ) / 9

	replace gdp_pc7074 = ln(gdp_pc7074)
		label var gdp_pc7074 "Log Real GDP per Worker - 1970-1974"

		
* --------------------
* Panel A: GDP Per Worker Growth
* --------------------

	*Full Sample
	reg  g_y_all  gdp_pc7074, robust
	reg  g_y_all  gdp_pc7074 $controls_GC , robust
	
	twoway (scatter g_y_all  gdp_pc7074  ) 										///
		(lfit g_y_all  gdp_pc7074), 											///
		title("Full Sample") 													///
		ylabel( -2 "-2%" -1 "-1%" 0 "0%" 1 "1%"  2 "2%" 3 "3%" 4 "4%" 5 "5%"  ) legend(off)	  xlabel(, grid gmax)   xtitle("")
	graph save "$dir/figures/temp/GDP Growth", replace
	
	*Energy Endowed Countries
	preserve
		keep if energyendowment==1

		reg  g_y_all  gdp_pc7074 , robust
		reg  g_y_all  gdp_pc7074 $controls_GC , robust
		
		twoway (scatter g_y_all  gdp_pc7074  ) 										///
			(lfit g_y_all  gdp_pc7074), 											///
			title("Energy-Endowed") 												///
			ylabel( -2 "-2%" -1 "-1%" 0 "0%" 1 "1%"  2 "2%" 3 "3%" 4 "4%" 5 "5%"  )   legend(off) xlabel(, grid gmax)   xtitle("")
		graph save "$dir/figures/temp/GDP Growth - Energy", replace
	restore
	
	*Non-Energy Endowed Countries
	preserve
		keep if energyendowment==0

		reg  g_y_all  gdp_pc7074 , robust
		reg  g_y_all  gdp_pc7074 $controls_GC , robust
				
		twoway (scatter g_y_all  gdp_pc7074  ) 										///
			(lfit g_y_all  gdp_pc7074), 											///
			title("Non-Energy-Endowed") 											///
			ylabel( -2 "-2%" -1 "-1%" 0 "0%" 1 "1%"  2 "2%" 3 "3%" 4 "4%" 5 "5%"  )   legend(off)	  xlabel(, grid gmax)   xtitle("")
		graph save "$dir/figures/temp/GDP Growth - Non-Energy", replace
	restore

	*Figure 3(a) - GDP Per Worker Growth
	graph combine "$dir/figures/temp/GDP Growth"				///
			"$dir/figures/temp/GDP Growth - Energy"				///
			"$dir/figures/temp/GDP Growth - Non-Energy"				///
			, ycommon xcommon													///
			l1title("Average Annual Growth Rate")  b1title("Log Real GDP Per Worker 1970-1974") 	///
			rows(1)   ysize(1.5)  xsize(4.5)		
	graph export "$dir/figures/Figure 3a - Convergence of Growth Componenets - GDP Per Worker Growth.png" , replace	
	
	
	
* --------------------
* Panel B: Capital Per Worker Growth
* --------------------
	*Full Sample
	reg  g_k_all  gdp_pc7074, robust
	reg  g_k_all  gdp_pc7074 $controls_GC , robust
			
	twoway (scatter g_k_all  gdp_pc7074  ) 	///
		(lfit g_k_all  gdp_pc7074), 													///
		title("Full Sample") 													///
		ylabel( -2 "-2%" -1 "-1%" 0 "0%" 1 "1%"  2 "2%" 3 "3%" 4 "4%" 5 "5%" 6 "6%" 7 "7%" 8 "8%"   )  legend(off)	  xlabel(, grid gmax)   xtitle("")
	
	graph save "$dir/figures/temp/Capital Growth", replace

	*Energy Endowed Countries
	preserve 
	keep if energyendowment==1
	
		reg  g_k_all  gdp_pc7074, robust
		reg  g_k_all  gdp_pc7074 $controls_GC  , robust
		
		twoway (scatter g_k_all  gdp_pc7074  ) 	///
			(lfit g_k_all  gdp_pc7074), 													///
			title("Energy-Endowed") 													///
			ylabel( -2 "-2%" -1 "-1%" 0 "0%" 1 "1%"  2 "2%" 3 "3%" 4 "4%" 5 "5%" 6 "6%" 7 "7%" 8 "8%" ) legend(off) xlabel(, grid gmax)   xtitle("")

		graph save "$dir/figures/temp/Capital Growth - Energy", replace
	restore

	*Non-Energy Endowed Countries
	preserve 
	keep if energyendowment==0
	
		reg  g_k_all  gdp_pc7074, robust
		reg  g_k_all  gdp_pc7074 $controls_GC  , robust
	
		twoway (scatter g_k_all  gdp_pc7074  ) 	///
			(lfit g_k_all  gdp_pc7074), 													///
			title("Non-Energy-Endowed") 													///
			ylabel( -2 "-2%" -1 "-1%" 0 "0%" 1 "1%"  2 "2%" 3 "3%" 4 "4%" 5 "5%" 6 "6%" 7 "7%" 8 "8%"   ) legend(off)	  xlabel(, grid gmax)   xtitle("")

	graph save "$dir/figures/temp/Capital Growth - Non-Energy", replace
	restore

	*Capital
	graph combine "$dir/figures/temp/Capital Growth"				///
		"$dir/figures/temp/Capital Growth - Energy"				///
		"$dir/figures/temp/Capital Growth - Non-Energy"				///
		, ycommon xcommon													///
		l1title("Average Annual Growth Rate")  b1title("Log Real GDP Per Worker 1970-1974") 	///
		rows(1)   ysize(1.5)  xsize(4.5)				
	graph export "$dir/figures/Figure 3b - Convergence of Growth Componenets - Capital Per Worker Growth.png" , replace	
	
* --------------------
* Panel C: Human Capital Growth
* --------------------

	*Full Sample
	reg  g_hc_all  gdp_pc7074, robust
	reg  g_hc_all  gdp_pc7074 $controls_GC , robust
		
	twoway (scatter g_hc_all  gdp_pc7074  ) 	///
		(lfit g_hc_all  gdp_pc7074), 													///
		title("Full Sample") 													///
		ylabel(  0 "0%" .5 "0.5%" 1 "1%"  1.5 "1.5%"  2 "2%" ) legend(off)	  xlabel(, grid gmax)   xtitle("")
	
	graph save "$dir/figures/temp/Human Capital Growth", replace
	
	*Energy Endowed Countries
	preserve 
	keep if energyendowment==1
	
		reg  g_hc_all  gdp_pc7074, robust
		reg  g_hc_all  gdp_pc7074 $controls_GC  , robust
		
		twoway (scatter g_hc_all  gdp_pc7074  ) 	///
		(lfit g_hc_all  gdp_pc7074), 													///
		title("Energy-Endowed") 													///
		ylabel(  0 "0%" .5 "0.5%" 1 "1%"  1.5 "1.5%"  2 "2%" ) legend(off)	  xlabel(, grid gmax)   xtitle("")

		graph save "$dir/figures/temp/Human Capital Growth - Energy", replace
	restore

	*Non-Energy Endowed Countries
	preserve 
	keep if energyendowment==0
	
		reg  g_hc_all  gdp_pc7074, robust
		reg  g_hc_all  gdp_pc7074 $controls_GC  , robust
		
		twoway (scatter g_hc_all  gdp_pc7074  ) 	///
		(lfit g_hc_all  gdp_pc7074), 													///
		title("Non-Energy-Endowed") 													///
		ylabel(  0 "0%" .5 "0.5%" 1 "1%"  1.5 "1.5%"  2 "2%" ) legend(off)	  xlabel(, grid gmax)   xtitle("")

		graph save "$dir/figures/temp/Human Capital Growth - Non-Energy", replace
		
	restore

	graph combine "$dir/figures/temp/Human Capital Growth"				///
		"$dir/figures/temp/Human Capital Growth - Energy"				///
		"$dir/figures/temp/Human Capital Growth - Non-Energy"				///
		, ycommon xcommon 												///
		l1title("Average Annual Growth Rate")  b1title("Log Real GDP Per Worker 1970-1974") 	///
		rows(1)   ysize(1.5)  xsize(4.5)
	graph export "$dir/figures/Figure 3c - Convergence of Growth Componenets - Human Capital Growth.png" , replace	
	
	
* --------------------
* Panel D: Total Factor Productivity Growth
* --------------------

	*Full Sample
	reg  g_tfp_all  gdp_pc7074, robust
	reg  g_tfp_all  gdp_pc7074 $controls_GC , robust
	
	twoway (scatter g_tfp_all  gdp_pc7074  ) 	///
		(lfit g_tfp_all  gdp_pc7074), 													///
		title("Full Sample") 													///
		ylabel( -3 "-3%" -2 "-2%" -1 "-1%" 0 "0%" 1 "1%"  2 "2%"  ) legend(off)	  xlabel(, grid gmax)   xtitle("")
	
	graph save "$dir/figures/temp/TFP Growth", replace
	
	*Energy Endowed Countries
	preserve 
		keep if energyendowment==1
		
		reg  g_tfp_all  gdp_pc7074, robust
		reg  g_tfp_all  gdp_pc7074 $controls_GC  , robust
		
		twoway (scatter g_tfp_all  gdp_pc7074  ) 	///
			(lfit g_tfp_all  gdp_pc7074), 													///
			title("Energy-Endowed") 													///
			ylabel( -3 "-3%" -2 "-2%" -1 "-1%" 0 "0%" 1 "1%"  2 "2%"  ) legend(off)	  xlabel(, grid gmax)   xtitle("")
	
		graph save "$dir/figures/temp/TFP Growth - Energy", replace
	restore

	*Non-Energy Endowed Countries
	preserve 
		keep if energyendowment==0
	
		reg  g_tfp_all  gdp_pc7074, robust
		reg  g_tfp_all  gdp_pc7074 $controls_GC  , robust
		
		twoway (scatter g_tfp_all  gdp_pc7074  ) 								///
		(lfit g_tfp_all  gdp_pc7074), 											///
		title("Non-Energy-Endowed") 											///
		ylabel( -3 "-3%" -2 "-2%" -1 "-1%" 0 "0%" 1 "1%"  2 "2%"  ) legend(off)	  xlabel(, grid gmax)   xtitle("")

		graph save "$dir/figures/temp/TFP Growth - Non-Energy", replace
	restore
	
	*TFP Capital
	graph combine "$dir/figures/temp/TFP Growth"			///
		"$dir/figures/temp/TFP Growth - Energy"			///
		"$dir/figures/temp/TFP Growth - Non-Energy"				///
		, ycommon xcommon 													///
		l1title("Average Annual Growth Rate")  b1title("Log Real GDP Per Worker 1970-1974") 	///
		rows(1)   ysize(1.5)  xsize(4.5)
	graph export "$dir/figures/Figure 3d - Convergence of Growth Componenets - TFP Growth.png" , replace	


